@@ -47,7 +47,7 @@ getRVersionString = function() {
 #   Default is the config setting.
 # @return [logical(1)]
 checkUserConfirmation = function(type, confirm.upload = NULL) {
-  assertChoice(type, choices = c("dataset", "flow", "task", "run"))
+  assertChoice(type, choices = c("dataset", "flow", "task", "run", "study"))
   if (is.null(confirm.upload)) {
     confirm.upload = as.logical(getOMLConfig()$confirm.upload)
   }
@@ -74,7 +74,7 @@ arff.writer = function(x, file){
 }
 
 getValidOMLDataSetStatusLevels = function() {
-  c("active", "deactivated", "in_preparation")
+  c("active", "deactivated", "in_preparation", "all")
 }
 
 catfNotNA = function(text, obj) {
@@ -137,6 +137,7 @@ generateAPICall = function(api.call, task.id = NULL, flow.id = NULL,
   if (!is.null(status)) assertChoice(status, choices = getValidOMLDataSetStatusLevels())
   if (!is.null(evaluation.measure))
     evaluation.measure = assertChoice(evaluation.measure, choices = listOMLEvaluationMeasures(verbosity = 0)$name)
+  #if (!is.null(main_entity_type)) assertChoice(main_entity_type, choices = c("task", "run"))
 
   url.args = list(
     "task" = task.id,
@@ -155,6 +156,7 @@ generateAPICall = function(api.call, task.id = NULL, flow.id = NULL,
     "function" = evaluation.measure,
     "limit" = limit,
     "offset" = offset,
+    #"main_entity_type" = main_entity_type,
     "status" = status
   )
   url.args = Filter(function(x) !is.null(x), url.args)
